@@ -5,7 +5,7 @@ use 5.008001;
 use bytes;
 use Fcntl ':seek';
 use Carp ();
-our $VERSION = '0.08';
+our $VERSION = '0.09';
 our @ISA = qw/Exporter/;
 our @EXPORT = ('is_jpeg');
 
@@ -64,7 +64,7 @@ sub _is_jpeg {
         if ($marker ne SECTION_MARKER) {
             return 0; # invalid marker
         } elsif (($code >= SIZE_FIRST) && ($code <= SIZE_LAST)) {
-            return _check_eoi($fh); # got a size info
+            return 1; # got a size info
         } else {
             seek $fh, $len-2, SEEK_CUR; # skip segment body
         }
@@ -72,31 +72,6 @@ sub _is_jpeg {
     die "should not reach here";
 }
 
-sub _check_eoi {
-    my $fh = shift;
-    return 0 if seek($fh, -2, SEEK_END) == 0;
-    return 0 if read($fh, my $buf, 2)   != 2;
-    return _skip_stuffing($fh) if $buf ne EOI;
-    return 1; # success!
-}
-
-sub _skip_stuffing {
-    my $fh = shift;
-    my $seek = READ_SIZE;
-    my $size = tell($fh);
-    my $buf = '';
-    my $len;
-
-    while ($seek <= $size) {
-        return 0 if seek($fh, -$seek, SEEK_END) == 0;
-        return 0 if ($len = read($fh, my $rbuf, READ_SIZE)) < 0;
-        $buf = $rbuf . $buf;
-        $buf =~ s/\xff$//;
-        return 1 if $buf =~ EOI_RE;
-        $seek += $len;
-    }
-}
-
 1;
 __END__
 
